@@ -1,6 +1,6 @@
 package Mongoose;
 BEGIN {
-  $Mongoose::VERSION = '0.01';
+  $Mongoose::VERSION = '0.02';
 }
 use MongoDB;
 use MooseX::Singleton;
@@ -76,7 +76,7 @@ Mongoose - MongoDB document to Moose object mapper
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -118,7 +118,7 @@ Or proceed directly to the L<Mongoose::Cookbook> for many day-to-day recipes.
 
 =begin html
 
-<img src="http://cpansearch.perl.org/src/RODRIGO/Mongoose-0.01_02/etc/mongoose_icon.png" />
+<img src="http://cpansearch.perl.org/src/RODRIGO/Mongoose-0.01/etc/mongoose_icon.png" />
 
 =end html
 
@@ -223,4 +223,13 @@ Report bugs via RT. Send me test cases.
 
 =head1 SEE ALSO
 
-L<KiokuDB>
\ No newline at end of file
+L<KiokuDB>
+
+=head1 AUTHOR
+
+	Rodrigo de Oliveira (rodrigolive), C<rodrigolive@gmail.com>
+
+=head1 LICENSE
+
+This library is free software. You can redistribute it and/or modify it under
+the same terms as Perl itself.
\ No newline at end of file
